@@ -82,9 +82,12 @@ private:
   void Unselect();
   void FadeInitial();
   void Fade();
-  void DrawCardInternal(size_t row, size_t column);
-  void DrawCard(size_t row, size_t column);
-  void DrawCard(size_t index);
+  void DrawCardInternal(Lum::OS::DrawInfo* draw,
+                        size_t row, size_t column);
+  void DrawCard(Lum::OS::DrawInfo* draw,
+                size_t row, size_t column);
+  void DrawCard(Lum::OS::DrawInfo* draw,
+                size_t index);
 
 public:
   CardArea();
@@ -101,7 +104,8 @@ public:
 
   void CalcSize();
 
-  void Draw(int x, int y, size_t w, size_t h);
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int y, size_t w, size_t h);
 
   bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
   void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
