@@ -22,7 +22,6 @@
 #include <iostream>
 
 #include <Lum/Base/L10N.h>
-#include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
 #include <Lum/Def/Menu.h>
@@ -34,8 +33,9 @@
 
 #include <Lum/Model/Action.h>
 
-#include <Lum/OS/Main.h>
+#include <Lum/Manager/FileSystem.h>
 
+#include <Lum/Application.h>
 #include <Lum/Button.h>
 #include <Lum/Dialog.h>
 #include <Lum/Grid.h>
@@ -917,21 +917,10 @@ public:
   }
 };
 
-class Main : public Lum::OS::MainDialog<MainDialog>
+class Main : public Lum::GUIApplication<MainDialog>
 {
 public:
-  bool Prepare()
-  {
-#if defined(APP_DATADIR)
-    Lum::Base::Path::SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
-#endif
-
-    srand(time(NULL));
-
-   return Lum::OS::MainDialog<MainDialog>::Prepare();
-  }
-
-  Main()
+  bool Initialize()
   {
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
     info.SetVersion(Lum::Base::StringToWString(PACKAGE_VERSION));
@@ -940,6 +929,14 @@ public:
     info.SetContact(L"Tim Teulings <tim@teulings.org>");
     info.SetCopyright(L"(c) 2007, Tim Teulings");
     info.SetLicense(L"GNU Public License");
+  
+#if defined(APP_DATADIR)
+    Lum::Manager::FileSystem::Instance()->SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
+#endif
+
+    srand(time(NULL));
+
+   return Lum::GUIApplication<MainDialog>::Initialize();
   }
 };
 
