@@ -23,7 +23,7 @@
 
 #include <Lum/Base/String.h>
 
-#include <Lum/OS/Main.h>
+#include <Lum/Application.h>
 
 #include "Heap.h"
 #include "PlayerGoal.h"
@@ -40,10 +40,10 @@
 //#define GAMES 1000
 //#define GAMES 1
 
-class Main : public Lum::OS::MainIllumination
+class ScopaTest : public Lum::IlluminationApplication
 {
 public:
-  bool Body()
+  bool Main()
   {
     std::cout << "Starting..." << std::endl;
 
@@ -318,8 +318,8 @@ public:
 
     std::cout << "done." << std::endl;
 
-    return 0;
+    return true;
   }
 };
 
-LUM_MAIN(Main,L"ScopaTest")
+LUM_MAIN(ScopaTest,L"ScopaTest")
